@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -55,13 +55,14 @@ import org.apache.commons.io.filefilter.NameFileFilter;
 import org.apache.commons.io.test.TestUtils;
 import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.SystemProperties;
 import org.apache.commons.lang3.SystemUtils;
 import org.junit.jupiter.api.Test;
 
 /**
  * Tests {@link PathUtils}.
  */
-public class PathUtilsTest extends AbstractTempDirTest {
+class PathUtilsTest extends AbstractTempDirTest {
 
     private static final String STRING_FIXTURE = "Hello World";
 
@@ -73,24 +74,6 @@ public class PathUtilsTest extends AbstractTempDirTest {
 
     private static final String PATH_FIXTURE = "NOTICE.txt";
 
-    /**
-     * Creates directory test fixtures.
-     * <ol>
-     * <li>tempDirPath/subdir</li>
-     * <li>tempDirPath/symlinked-dir -> tempDirPath/subdir</li>
-     * </ol>
-     *
-     * @return Path to tempDirPath/subdir
-     * @throws IOException if an I/O error occurs or the parent directory does not exist.
-     */
-    private Path createTempSymlinkedRelativeDir() throws IOException {
-        final Path targetDir = tempDirPath.resolve("subdir");
-        final Path symlinkDir = tempDirPath.resolve("symlinked-dir");
-        Files.createDirectory(targetDir);
-        Files.createSymbolicLink(symlinkDir, targetDir);
-        return symlinkDir;
-    }
-
     private Path current() {
         return PathUtils.current();
     }
@@ -119,7 +102,7 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testCopyDirectoryForDifferentFilesystemsWithAbsolutePath() throws IOException {
+    void testCopyDirectoryForDifferentFilesystemsWithAbsolutePath() throws IOException {
         final Path archivePath = Paths.get(TEST_JAR_PATH);
         try (FileSystem archive = openArchive(archivePath, false)) {
             // relative jar -> absolute dir
@@ -135,7 +118,7 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testCopyDirectoryForDifferentFilesystemsWithAbsolutePathReverse() throws IOException {
+    void testCopyDirectoryForDifferentFilesystemsWithAbsolutePathReverse() throws IOException {
         try (FileSystem archive = openArchive(tempDirPath.resolve(TEST_JAR_NAME), true)) {
             // absolute dir -> relative jar
             Path targetDir = archive.getPath("target");
@@ -152,9 +135,10 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testCopyDirectoryForDifferentFilesystemsWithRelativePath() throws IOException {
+    void testCopyDirectoryForDifferentFilesystemsWithRelativePath() throws IOException {
         final Path archivePath = Paths.get(TEST_JAR_PATH);
-        try (FileSystem archive = openArchive(archivePath, false); final FileSystem targetArchive = openArchive(tempDirPath.resolve(TEST_JAR_NAME), true)) {
+        try (FileSystem archive = openArchive(archivePath, false);
+                FileSystem targetArchive = openArchive(tempDirPath.resolve(TEST_JAR_NAME), true)) {
             final Path targetDir = targetArchive.getPath("targetDir");
             Files.createDirectory(targetDir);
             // relative jar -> relative dir
@@ -170,7 +154,7 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testCopyDirectoryForDifferentFilesystemsWithRelativePathReverse() throws IOException {
+    void testCopyDirectoryForDifferentFilesystemsWithRelativePathReverse() throws IOException {
         try (FileSystem archive = openArchive(tempDirPath.resolve(TEST_JAR_NAME), true)) {
             // relative dir -> relative jar
             Path targetDir = archive.getPath("target");
@@ -187,7 +171,7 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testCopyFile() throws IOException {
+    void testCopyFile() throws IOException {
         final Path sourceFile = Paths.get("src/test/resources/org/apache/commons/io/dirs-1-file-size-1/file-size-1.bin");
         final Path targetFile = PathUtils.copyFileToDirectory(sourceFile, tempDirPath);
         assertTrue(Files.exists(targetFile));
@@ -195,7 +179,17 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testCopyURL() throws IOException {
+    void testCopyFileTwoFileSystem() throws IOException {
+        try (FileSystem archive = openArchive(Paths.get(TEST_JAR_PATH), false)) {
+            final Path sourceFile = archive.getPath("next/dir/test.log");
+            final Path targetFile = PathUtils.copyFileToDirectory(sourceFile, tempDirPath);
+            assertTrue(Files.exists(targetFile));
+            assertEquals(Files.size(sourceFile), Files.size(targetFile));
+        }
+    }
+
+    @Test
+    void testCopyURL() throws IOException {
         final Path sourceFile = Paths.get("src/test/resources/org/apache/commons/io/dirs-1-file-size-1/file-size-1.bin");
         final URL url = new URL("file:///" + FilenameUtils.getPath(sourceFile.toAbsolutePath().toString()) + sourceFile.getFileName());
         final Path targetFile = PathUtils.copyFileToDirectory(url, tempDirPath);
@@ -204,13 +198,13 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testCreateDirectoriesAlreadyExists() throws IOException {
+    void testCreateDirectoriesAlreadyExists() throws IOException {
         assertEquals(tempDirPath.getParent(), PathUtils.createParentDirectories(tempDirPath));
     }
 
     @SuppressWarnings("resource") // FileSystems.getDefault() is a singleton
     @Test
-    public void testCreateDirectoriesForRoots() throws IOException {
+    void testCreateDirectoriesForRoots() throws IOException {
         for (final Path path : FileSystems.getDefault().getRootDirectories()) {
             final Path parent = path.getParent();
             assertNull(parent);
@@ -219,7 +213,7 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testCreateDirectoriesForRootsLinkOptionNull() throws IOException {
+    void testCreateDirectoriesForRootsLinkOptionNull() throws IOException {
         for (final File f : File.listRoots()) {
             final Path path = f.toPath();
             assertEquals(path.getParent(), PathUtils.createParentDirectories(path, (LinkOption) null));
@@ -227,63 +221,144 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testCreateDirectoriesNew() throws IOException {
+    void testCreateDirectoriesNew() throws IOException {
         assertEquals(tempDirPath, PathUtils.createParentDirectories(tempDirPath.resolve("child")));
     }
 
     @Test
-    public void testCreateDirectoriesSymlink() throws IOException {
-        final Path symlinkedDir = createTempSymlinkedRelativeDir();
+    void testCreateDirectoriesSymlink() throws IOException {
+        final Path symlinkedDir = createTempSymbolicLinkedRelativeDir(tempDirPath);
         final String leafDirName = "child";
         final Path newDirFollowed = PathUtils.createParentDirectories(symlinkedDir.resolve(leafDirName), PathUtils.NULL_LINK_OPTION);
         assertEquals(Files.readSymbolicLink(symlinkedDir), newDirFollowed);
     }
 
     @Test
-    public void testCreateDirectoriesSymlinkClashing() throws IOException {
-        final Path symlinkedDir = createTempSymlinkedRelativeDir();
+    void testCreateDirectoriesSymlinkClashing() throws IOException {
+        final Path symlinkedDir = createTempSymbolicLinkedRelativeDir(tempDirPath);
         assertEquals(symlinkedDir, PathUtils.createParentDirectories(symlinkedDir.resolve("child")));
     }
 
     @Test
-    public void testGetLastModifiedFileTime_File_Present() throws IOException {
+    void testGetBaseNamePathBaseCases() {
+        assertEquals("bar", PathUtils.getBaseName(Paths.get("a/b/c/bar.foo")));
+        assertEquals("foo", PathUtils.getBaseName(Paths.get("foo")));
+        assertEquals("", PathUtils.getBaseName(Paths.get("")));
+        assertEquals("", PathUtils.getBaseName(Paths.get(".")));
+        for (final File f : File.listRoots()) {
+            assertNull(PathUtils.getBaseName(f.toPath()));
+        }
+        if (SystemUtils.IS_OS_WINDOWS) {
+            assertNull(PathUtils.getBaseName(Paths.get("C:\\")));
+        }
+    }
+
+    @Test
+    void testGetBaseNamePathCornerCases() {
+        assertNull(PathUtils.getBaseName((Path) null));
+        assertEquals("foo", PathUtils.getBaseName(Paths.get("foo.")));
+        assertEquals("", PathUtils.getBaseName(Paths.get("bar/.foo")));
+    }
+
+    @Test
+    void testGetDosFileAttributeView() {
+        // dir
+        final DosFileAttributeView dosFileAttributeView = PathUtils.getDosFileAttributeView(current());
+        final Path path = Paths.get("this-file-does-not-exist-at.all");
+        assertFalse(Files.exists(path));
+        if (SystemUtils.IS_OS_MAC) {
+            assertNull(dosFileAttributeView);
+            // missing file
+            assertNull(PathUtils.getDosFileAttributeView(path));
+        } else {
+            assertNotNull(dosFileAttributeView);
+            // missing file
+            assertNotNull(PathUtils.getDosFileAttributeView(path));
+        }
+        // null
+        assertThrows(NullPointerException.class, () -> PathUtils.getDosFileAttributeView(null));
+    }
+
+    @Test
+    void testGetExtension() {
+        assertNull(PathUtils.getExtension(null));
+        assertEquals("ext", PathUtils.getExtension(Paths.get("file.ext")));
+        assertEquals("", PathUtils.getExtension(Paths.get("README")));
+        assertEquals("com", PathUtils.getExtension(Paths.get("domain.dot.com")));
+        assertEquals("jpeg", PathUtils.getExtension(Paths.get("image.jpeg")));
+        assertEquals("", PathUtils.getExtension(Paths.get("a.b/c")));
+        assertEquals("txt", PathUtils.getExtension(Paths.get("a.b/c.txt")));
+        assertEquals("", PathUtils.getExtension(Paths.get("a/b/c")));
+        assertEquals("", PathUtils.getExtension(Paths.get("a.b\\c")));
+        assertEquals("txt", PathUtils.getExtension(Paths.get("a.b\\c.txt")));
+        assertEquals("", PathUtils.getExtension(Paths.get("a\\b\\c")));
+        assertEquals("", PathUtils.getExtension(Paths.get("C:\\temp\\foo.bar\\README")));
+        assertEquals("ext", PathUtils.getExtension(Paths.get("../filename.ext")));
+
+        if (File.separatorChar != '\\') {
+            // Upwards compatibility:
+            assertEquals("txt", PathUtils.getExtension(Paths.get("foo.exe:bar.txt")));
+        }
+    }
+
+    @Test
+    void testGetFileName() {
+        assertNull(PathUtils.getFileName(null, null));
+        assertNull(PathUtils.getFileName(null, Path::toString));
+        assertNull(PathUtils.getFileName(Paths.get("/"), Path::toString));
+        assertNull(PathUtils.getFileName(Paths.get("/"), Path::toString));
+        assertEquals("", PathUtils.getFileName(Paths.get(""), Path::toString));
+        assertEquals("a", PathUtils.getFileName(Paths.get("a"), Path::toString));
+        assertEquals("a", PathUtils.getFileName(Paths.get("p", "a"), Path::toString));
+    }
+
+    @Test
+    void testGetFileNameString() {
+        assertNull(PathUtils.getFileNameString(Paths.get("/")));
+        assertEquals("", PathUtils.getFileNameString(Paths.get("")));
+        assertEquals("a", PathUtils.getFileNameString(Paths.get("a")));
+        assertEquals("a", PathUtils.getFileNameString(Paths.get("p", "a")));
+    }
+
+    @Test
+    void testGetLastModifiedFileTime_File_Present() throws IOException {
         assertNotNull(PathUtils.getLastModifiedFileTime(current().toFile()));
     }
 
     @Test
-    public void testGetLastModifiedFileTime_Path_Absent() throws IOException {
+    void testGetLastModifiedFileTime_Path_Absent() throws IOException {
         assertNull(PathUtils.getLastModifiedFileTime(getNonExistentPath()));
     }
 
     @Test
-    public void testGetLastModifiedFileTime_Path_FileTime_Absent() throws IOException {
+    void testGetLastModifiedFileTime_Path_FileTime_Absent() throws IOException {
         final FileTime fromMillis = FileTime.fromMillis(0);
         assertEquals(fromMillis, PathUtils.getLastModifiedFileTime(getNonExistentPath(), fromMillis));
     }
 
     @Test
-    public void testGetLastModifiedFileTime_Path_Present() throws IOException {
+    void testGetLastModifiedFileTime_Path_Present() throws IOException {
         assertNotNull(PathUtils.getLastModifiedFileTime(current()));
     }
 
     @Test
-    public void testGetLastModifiedFileTime_URI_Present() throws IOException {
+    void testGetLastModifiedFileTime_URI_Present() throws IOException {
         assertNotNull(PathUtils.getLastModifiedFileTime(current().toUri()));
     }
 
     @Test
-    public void testGetLastModifiedFileTime_URL_Present() throws IOException, URISyntaxException {
+    void testGetLastModifiedFileTime_URL_Present() throws IOException, URISyntaxException {
         assertNotNull(PathUtils.getLastModifiedFileTime(current().toUri().toURL()));
     }
 
     @Test
-    public void testGetTempDirectory() {
-        final Path tempDirectory = Paths.get(System.getProperty("java.io.tmpdir"));
+    void testGetTempDirectory() {
+        final Path tempDirectory = Paths.get(SystemProperties.getJavaIoTmpdir());
         assertEquals(tempDirectory, PathUtils.getTempDirectory());
     }
 
     @Test
-    public void testIsDirectory() throws IOException {
+    void testIsDirectory() throws IOException {
         assertFalse(PathUtils.isDirectory(null));
 
         assertTrue(PathUtils.isDirectory(tempDirPath));
@@ -300,7 +375,7 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testIsPosix() throws IOException {
+    void testIsPosix() throws IOException {
         boolean isPosix;
         try {
             Files.getPosixFilePermissions(current());
@@ -312,7 +387,13 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testIsRegularFile() throws IOException {
+    void testIsPosixAbsentFile() {
+        assertFalse(PathUtils.isPosix(Paths.get("ImNotHereAtAllEver.never")));
+        assertFalse(PathUtils.isPosix(null));
+    }
+
+    @Test
+    void testIsRegularFile() throws IOException {
         assertFalse(PathUtils.isRegularFile(null));
 
         assertFalse(PathUtils.isRegularFile(tempDirPath));
@@ -325,47 +406,47 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testNewDirectoryStream() throws Exception {
+    void testNewDirectoryStream() throws Exception {
         final PathFilter pathFilter = new NameFileFilter(PATH_FIXTURE);
         try (DirectoryStream<Path> stream = PathUtils.newDirectoryStream(current(), pathFilter)) {
             final Iterator<Path> iterator = stream.iterator();
             final Path path = iterator.next();
-            assertEquals(PATH_FIXTURE, path.getFileName().toString());
+            assertEquals(PATH_FIXTURE, PathUtils.getFileNameString(path));
             assertFalse(iterator.hasNext());
         }
     }
 
     @Test
-    public void testNewOutputStreamExistingFileAppendFalse() throws IOException {
+    void testNewOutputStreamExistingFileAppendFalse() throws IOException {
         testNewOutputStreamNewFile(false);
         testNewOutputStreamNewFile(false);
     }
 
     @Test
-    public void testNewOutputStreamExistingFileAppendTrue() throws IOException {
+    void testNewOutputStreamExistingFileAppendTrue() throws IOException {
         testNewOutputStreamNewFile(true);
         final Path file = writeToNewOutputStream(true);
         assertArrayEquals(ArrayUtils.addAll(BYTE_ARRAY_FIXTURE, BYTE_ARRAY_FIXTURE), Files.readAllBytes(file));
     }
 
-    public void testNewOutputStreamNewFile(final boolean append) throws IOException {
+    void testNewOutputStreamNewFile(final boolean append) throws IOException {
         final Path file = writeToNewOutputStream(append);
         assertArrayEquals(BYTE_ARRAY_FIXTURE, Files.readAllBytes(file));
     }
 
     @Test
-    public void testNewOutputStreamNewFileAppendFalse() throws IOException {
+    void testNewOutputStreamNewFileAppendFalse() throws IOException {
         testNewOutputStreamNewFile(false);
     }
 
     @Test
-    public void testNewOutputStreamNewFileAppendTrue() throws IOException {
+    void testNewOutputStreamNewFileAppendTrue() throws IOException {
         testNewOutputStreamNewFile(true);
     }
 
     @Test
-    public void testNewOutputStreamNewFileInsideExistingSymlinkedDir() throws IOException {
-        final Path symlinkDir = createTempSymlinkedRelativeDir();
+    void testNewOutputStreamNewFileInsideExistingSymlinkedDir() throws IOException {
+        final Path symlinkDir = createTempSymbolicLinkedRelativeDir(tempDirPath);
         final Path file = symlinkDir.resolve("test.txt");
         try (OutputStream outputStream = PathUtils.newOutputStream(file, new LinkOption[] {})) {
             // empty
@@ -382,7 +463,7 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testReadAttributesPosix() throws IOException {
+    void testReadAttributesPosix() throws IOException {
         boolean isPosix;
         try {
             Files.getPosixFilePermissions(current());
@@ -394,14 +475,14 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testReadStringEmptyFile() throws IOException {
+    void testReadStringEmptyFile() throws IOException {
         final Path path = Paths.get("src/test/resources/org/apache/commons/io/test-file-empty.bin");
         assertEquals(StringUtils.EMPTY, PathUtils.readString(path, StandardCharsets.UTF_8));
         assertEquals(StringUtils.EMPTY, PathUtils.readString(path, null));
     }
 
     @Test
-    public void testReadStringSimpleUtf8() throws IOException {
+    void testReadStringSimpleUtf8() throws IOException {
         final Path path = Paths.get("src/test/resources/org/apache/commons/io/test-file-simple-utf8.bin");
         final String expected = "ABC\r\n";
         assertEquals(expected, PathUtils.readString(path, StandardCharsets.UTF_8));
@@ -409,7 +490,7 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testSetReadOnlyFile() throws IOException {
+    void testSetReadOnlyFile() throws IOException {
         final Path resolved = tempDirPath.resolve("testSetReadOnlyFile.txt");
         // Ask now, as we are allowed before editing parent permissions.
         final boolean isPosix = PathUtils.isPosix(tempDirPath);
@@ -470,7 +551,12 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testTouch() throws IOException {
+    void testSetReadOnlyFileAbsent() {
+        assertThrows(IOException.class, () -> PathUtils.setReadOnly(Paths.get("does-not-exist-at-all-ever-never"), true));
+    }
+
+    @Test
+    void testTouch() throws IOException {
         assertThrows(NullPointerException.class, () -> FileUtils.touch(null));
 
         final Path file = managedTempDirPath.resolve("touch.txt");
@@ -496,10 +582,10 @@ public class PathUtilsTest extends AbstractTempDirTest {
     }
 
     @Test
-    public void testWriteStringToFile1() throws Exception {
+    void testWriteStringToFile1() throws Exception {
         final Path file = tempDirPath.resolve("write.txt");
-        PathUtils.writeString(file, "Hello /u1234", StandardCharsets.UTF_8);
-        final byte[] text = "Hello /u1234".getBytes(StandardCharsets.UTF_8);
+        PathUtils.writeString(file, "Hello \u1234", StandardCharsets.UTF_8);
+        final byte[] text = "Hello \u1234".getBytes(StandardCharsets.UTF_8);
         TestUtils.assertEqualContent(text, file);
     }
 
