@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -73,7 +73,7 @@ public abstract class AbstractConditionalFileFilterTest extends AbstractIOFileFi
     }
 
     @Test
-    public void testAdd() {
+    void testAdd() {
         final List<TesterTrueFileFilter> filters = new ArrayList<>();
         final ConditionalFileFilter fileFilter = getConditionalFileFilter();
         filters.add(new TesterTrueFileFilter());
@@ -85,14 +85,12 @@ public abstract class AbstractConditionalFileFilterTest extends AbstractIOFileFi
             fileFilter.addFileFilter(filters.get(i));
             assertEquals(i + 1, fileFilter.getFileFilters().size(), "file filters count: ");
         }
-        fileFilter.getFileFilters().forEach(filter -> {
-            assertTrue(filters.contains(filter), "found file filter");
-        });
+        fileFilter.getFileFilters().forEach(filter -> assertTrue(filters.contains(filter), "found file filter"));
         assertEquals(filters.size(), fileFilter.getFileFilters().size(), "file filters count");
     }
 
     @Test
-    public void testFilterBuiltUsingAdd() {
+    void testFilterBuiltUsingAdd() {
         final List<List<IOFileFilter>> testFilters = getTestFilters();
         final List<boolean[]> testTrueResults = getTrueResults();
         final List<boolean[]> testFalseResults = getFalseResults();
@@ -126,7 +124,7 @@ public abstract class AbstractConditionalFileFilterTest extends AbstractIOFileFi
     }
 
     @Test
-    public void testFilterBuiltUsingConstructor() {
+    void testFilterBuiltUsingConstructor() {
         final List<List<IOFileFilter>> testFilters = getTestFilters();
         final List<boolean[]> testTrueResults = getTrueResults();
         final List<boolean[]> testFalseResults = getFalseResults();
@@ -160,7 +158,7 @@ public abstract class AbstractConditionalFileFilterTest extends AbstractIOFileFi
     }
 
     @Test
-    public void testNoFilters() {
+    void testNoFilters() {
         final ConditionalFileFilter fileFilter = getConditionalFileFilter();
         final File file = new File(this.workingPath, TEST_FILE_NAME_PREFIX + 1 + TEST_FILE_TYPE);
         assertFileFiltering(1, (IOFileFilter) fileFilter, file, false);
@@ -168,7 +166,7 @@ public abstract class AbstractConditionalFileFilterTest extends AbstractIOFileFi
     }
 
     @Test
-    public void testRemove() {
+    void testRemove() {
         final List<TesterTrueFileFilter> filters = new ArrayList<>();
         final ConditionalFileFilter fileFilter = getConditionalFileFilter();
         filters.add(new TesterTrueFileFilter());
