@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,6 +19,7 @@ package org.apache.commons.io.filefilter;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -54,12 +55,12 @@ import org.apache.commons.lang3.SystemUtils;
 import org.junit.jupiter.api.Test;
 
 /**
- * Used to test FileFilterUtils.
+ * Tests {@link FileFilterUtils}.
  */
-public class FileFilterTest extends AbstractFilterTest {
+class FileFilterTest extends AbstractFilterTest {
 
     @Test
-    public void testAgeFilter() throws Exception {
+    void testAgeFilter() throws Exception {
         final File oldFile = new File(temporaryFolder, "old.txt");
         final Path oldPath = oldFile.toPath();
         final File reference = new File(temporaryFolder, "reference.txt");
@@ -154,7 +155,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testAnd() throws IOException {
+    void testAnd() throws IOException {
         final IOFileFilter trueFilter = TrueFileFilter.INSTANCE;
         final IOFileFilter falseFilter = FalseFileFilter.INSTANCE;
         assertFiltering(trueFilter.and(trueFilter), new File("foo.test"), true);
@@ -164,7 +165,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testAnd2() throws IOException {
+    void testAnd2() throws IOException {
         final IOFileFilter trueFilter = TrueFileFilter.INSTANCE;
         final IOFileFilter falseFilter = FalseFileFilter.INSTANCE;
         assertFiltering(new AndFileFilter(trueFilter, trueFilter), new File("foo.test"), true);
@@ -182,7 +183,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testAndArray() throws IOException {
+    void testAndArray() throws IOException {
         final IOFileFilter trueFilter = TrueFileFilter.INSTANCE;
         final IOFileFilter falseFilter = FalseFileFilter.INSTANCE;
         assertFiltering(new AndFileFilter(trueFilter, trueFilter, trueFilter), new File("foo.test"), true);
@@ -196,7 +197,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testCanExecute() throws Exception {
+    void testCanExecute() throws Exception {
         assumeTrue(SystemUtils.IS_OS_WINDOWS);
         try (TempFile executablePath = TempFile.create(getClass().getSimpleName(), null)) {
             final File executableFile = executablePath.toFile();
@@ -205,15 +206,19 @@ public class FileFilterTest extends AbstractFilterTest {
             }
             assertTrue(executableFile.setExecutable(true));
             assertFiltering(CanExecuteFileFilter.CAN_EXECUTE, executablePath.get(), true);
+            assertFiltering(CanExecuteFileFilter.CAN_EXECUTE, (Path) null, false);
             assertFiltering(CanExecuteFileFilter.CAN_EXECUTE, executableFile, true);
+            assertFiltering(CanExecuteFileFilter.CAN_EXECUTE, (File) null, false);
             executableFile.setExecutable(false);
             assertFiltering(CanExecuteFileFilter.CANNOT_EXECUTE, executablePath.get(), false);
+            assertFiltering(CanExecuteFileFilter.CANNOT_EXECUTE, (Path) null, true);
             assertFiltering(CanExecuteFileFilter.CANNOT_EXECUTE, executableFile, false);
+            assertFiltering(CanExecuteFileFilter.CANNOT_EXECUTE, (File) null, true);
         }
     }
 
     @Test
-    public void testCanRead() throws Exception {
+    void testCanRead() throws Exception {
         final File readOnlyFile = new File(temporaryFolder, "read-only-file1.txt");
         final Path readOnlyPath = readOnlyFile.toPath();
         if (!readOnlyFile.getParentFile().exists()) {
@@ -224,16 +229,22 @@ public class FileFilterTest extends AbstractFilterTest {
         }
         assertTrue(readOnlyFile.setReadOnly());
         assertFiltering(CanReadFileFilter.CAN_READ, readOnlyFile, true);
+        assertFiltering(CanReadFileFilter.CAN_READ, (File) null, false);
         assertFiltering(CanReadFileFilter.CAN_READ, readOnlyPath, true);
+        assertFiltering(CanReadFileFilter.CAN_READ, (Path) null, false);
         assertFiltering(CanReadFileFilter.CANNOT_READ, readOnlyFile, false);
+        assertFiltering(CanReadFileFilter.CANNOT_READ, (File) null, true);
         assertFiltering(CanReadFileFilter.CANNOT_READ, readOnlyPath, false);
+        assertFiltering(CanReadFileFilter.CANNOT_READ, (Path) null, true);
         assertFiltering(CanReadFileFilter.READ_ONLY, readOnlyFile, true);
+        assertFiltering(CanReadFileFilter.READ_ONLY, (File) null, false);
         assertFiltering(CanReadFileFilter.READ_ONLY, readOnlyPath, true);
+        assertFiltering(CanReadFileFilter.READ_ONLY, (Path) null, false);
         readOnlyFile.delete();
     }
 
     @Test
-    public void testCanWrite() throws Exception {
+    void testCanWrite() throws Exception {
         final File readOnlyFile = new File(temporaryFolder, "read-only-file2.txt");
         final Path readOnlyPath = readOnlyFile.toPath();
         if (!readOnlyFile.getParentFile().exists()) {
@@ -244,16 +255,20 @@ public class FileFilterTest extends AbstractFilterTest {
         }
         assertTrue(readOnlyFile.setReadOnly());
         assertFiltering(CanWriteFileFilter.CAN_WRITE, temporaryFolder, true);
-        assertFiltering(CanWriteFileFilter.CANNOT_WRITE, temporaryFolder, false);
         assertFiltering(CanWriteFileFilter.CAN_WRITE, readOnlyFile, false);
+        assertFiltering(CanWriteFileFilter.CAN_WRITE, (File) null, false);
         assertFiltering(CanWriteFileFilter.CAN_WRITE, readOnlyPath, false);
+        assertFiltering(CanWriteFileFilter.CAN_WRITE, (Path) null, false);
+        assertFiltering(CanWriteFileFilter.CANNOT_WRITE, temporaryFolder, false);
         assertFiltering(CanWriteFileFilter.CANNOT_WRITE, readOnlyFile, true);
         assertFiltering(CanWriteFileFilter.CANNOT_WRITE, readOnlyPath, true);
+        assertFiltering(CanWriteFileFilter.CANNOT_WRITE, (File) null, true);
+        assertFiltering(CanWriteFileFilter.CANNOT_WRITE, (Path) null, true);
         readOnlyFile.delete();
     }
 
     @Test
-    public void testDelegateFileFilter() throws IOException {
+    void testDelegateFileFilter() throws IOException {
         final OrFileFilter orFilter = new OrFileFilter();
         final File testFile = new File("test.txt");
 
@@ -270,14 +285,14 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testDelegation() { // TODO improve these tests
+    void testDelegation() { // TODO improve these tests
         assertNotNull(FileFilterUtils.asFileFilter((FileFilter) FalseFileFilter.INSTANCE));
         assertNotNull(FileFilterUtils.asFileFilter((FilenameFilter) FalseFileFilter.INSTANCE).toString());
     }
 
     @SuppressWarnings("deprecation")
     @Test
-    public void testDeprecatedWildcard() throws IOException {
+    void testDeprecatedWildcard() throws IOException {
         IOFileFilter filter = new WildcardFilter("*.txt");
         final List<String> patternList = Arrays.asList("*.txt", "*.xml", "*.gif");
         final IOFileFilter listFilter = new WildcardFilter(patternList);
@@ -356,7 +371,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testDirectory() throws IOException {
+    void testDirectory() throws IOException {
         // XXX: This test presumes the current working dir is the base dir of the source checkout.
         final IOFileFilter filter = new DirectoryFileFilter();
 
@@ -376,11 +391,14 @@ public class FileFilterTest extends AbstractFilterTest {
         assertFiltering(filter, new File("LICENSE.txt"), false);
         assertFiltering(filter, new File("LICENSE.txt").toPath(), false);
 
+        assertFiltering(filter, (File) null, false);
+        assertFiltering(filter, (Path) null, false);
+
         assertSame(DirectoryFileFilter.DIRECTORY, DirectoryFileFilter.INSTANCE);
     }
 
     @Test
-    public void testEmpty() throws Exception {
+    void testEmpty() throws Exception {
 
         // Empty Dir
         final File emptyDirFile = new File(temporaryFolder, "empty-dir");
@@ -388,8 +406,12 @@ public class FileFilterTest extends AbstractFilterTest {
         emptyDirFile.mkdirs();
         assertFiltering(EmptyFileFilter.EMPTY, emptyDirFile, true);
         assertFiltering(EmptyFileFilter.EMPTY, emptyDirPath, true);
+        assertFiltering(EmptyFileFilter.EMPTY, (File) null, true);
+        assertFiltering(EmptyFileFilter.EMPTY, (Path) null, true);
         assertFiltering(EmptyFileFilter.NOT_EMPTY, emptyDirFile, false);
         assertFiltering(EmptyFileFilter.NOT_EMPTY, emptyDirPath, false);
+        assertFiltering(EmptyFileFilter.NOT_EMPTY, (File) null, false);
+        assertFiltering(EmptyFileFilter.NOT_EMPTY, (Path) null, false);
 
         // Empty File
         final File emptyFile = new File(emptyDirFile, "empty-file.txt");
@@ -428,12 +450,12 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testEnsureTestCoverage() {
+    void testEnsureTestCoverage() {
         assertNotNull(new FileFilterUtils()); // dummy for test coverage
     }
 
     @Test
-    public void testFalse() throws IOException {
+    void testFalse() throws IOException {
         final IOFileFilter filter = FileFilterUtils.falseFileFilter();
         assertFiltering(filter, new File("foo.test"), false);
         assertFiltering(filter, new File("foo.test").toPath(), false);
@@ -448,13 +470,13 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testFileEqualsFilter() throws IOException {
+    void testFileEqualsFilter() throws IOException {
         assertFooBarFileFiltering(
             new FileEqualsFileFilter(new File("foo")).or(new FileEqualsFileFilter(new File("bar"))));
     }
 
     @Test
-    public void testFileFilterUtils_and() throws IOException {
+    void testFileFilterUtils_and() throws IOException {
         final IOFileFilter trueFilter = TrueFileFilter.INSTANCE;
         final IOFileFilter falseFilter = FalseFileFilter.INSTANCE;
         assertFiltering(FileFilterUtils.and(trueFilter, trueFilter, trueFilter), new File("foo.test"), true);
@@ -464,7 +486,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testFileFilterUtils_or() throws IOException {
+    void testFileFilterUtils_or() throws IOException {
         final IOFileFilter trueFilter = TrueFileFilter.INSTANCE;
         final IOFileFilter falseFilter = FalseFileFilter.INSTANCE;
         final File testFile = new File("foo.test");
@@ -475,10 +497,11 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testFiles() throws IOException {
+    void testFiles() throws IOException {
         // XXX: This test presumes the current working dir is the base dir of the source checkout.
         final IOFileFilter filter = FileFileFilter.INSTANCE;
 
+        assertFiltering(filter, (File) null, false);
         assertFiltering(filter, new File("src/"), false);
         assertFiltering(filter, new File("src/").toPath(), false);
         assertFiltering(filter, new File("src/java/"), false);
@@ -501,7 +524,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * properly filters files from the list.
      */
     @Test
-    public void testFilterArray_fromList() throws Exception {
+    void testFilterArray_fromList() throws Exception {
         final File fileA = TestUtils.newFile(temporaryFolder, "A");
         final File fileB = TestUtils.newFile(temporaryFolder, "B");
         final List<File> fileList = Arrays.asList(fileA, fileB);
@@ -519,7 +542,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * files from the list.
      */
     @Test
-    public void testFilterArray_IOFileFilter() throws Exception {
+    void testFilterArray_IOFileFilter() throws Exception {
         final File fileA = TestUtils.newFile(temporaryFolder, "A");
         final File fileB = TestUtils.newFile(temporaryFolder, "B");
 
@@ -536,7 +559,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * files from the list.
      */
     @Test
-    public void testFilterArray_PathVisitorFileFilter_FileExistsNo() throws Exception {
+    void testFilterArray_PathVisitorFileFilter_FileExistsNo() throws Exception {
         final File fileA = TestUtils.newFile(temporaryFolder, "A");
         final File fileB = TestUtils.newFile(temporaryFolder, "B");
 
@@ -553,7 +576,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * files from the list.
      */
     @Test
-    public void testFilterArray_PathVisitorFileFilter_FileExistsYes() throws Exception {
+    void testFilterArray_PathVisitorFileFilter_FileExistsYes() throws Exception {
         final File fileA = TestUtils.newFile(temporaryFolder, "A");
         final File fileB = TestUtils.newFile(temporaryFolder, "B");
         FileUtils.write(fileA, "test", StandardCharsets.US_ASCII);
@@ -570,7 +593,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * Test method for {@link FileFilterUtils#filter(IOFileFilter, File...)} that tests {@code null} parameters.
      */
     @Test
-    public void testFilterFilesArrayNullParameters() throws Exception {
+    void testFilterFilesArrayNullParameters() throws Exception {
         final File fileA = TestUtils.newFile(temporaryFolder, "A");
         final File fileB = TestUtils.newFile(temporaryFolder, "B");
         assertThrows(NullPointerException.class, () -> FileFilterUtils.filter(null, fileA, fileB));
@@ -587,7 +610,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * properly filters files from the list.
      */
     @Test
-    public void testFilterList() throws Exception {
+    void testFilterList() throws Exception {
         final File fileA = TestUtils.newFile(temporaryFolder, "A");
         final File fileB = TestUtils.newFile(temporaryFolder, "B");
         final List<File> fileList = Arrays.asList(fileA, fileB);
@@ -605,7 +628,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * filters files from the list.
      */
     @Test
-    public void testFilterList_fromArray() throws Exception {
+    void testFilterList_fromArray() throws Exception {
         final File fileA = TestUtils.newFile(temporaryFolder, "A");
         final File fileB = TestUtils.newFile(temporaryFolder, "B");
 
@@ -622,13 +645,13 @@ public class FileFilterTest extends AbstractFilterTest {
      * parameters and {@code null} elements in the provided list.
      */
     @Test
-    public void testFilterListNullParameters() {
+    void testFilterListNullParameters() {
         assertThrows(NullPointerException.class, () -> FileFilterUtils.filterList(null, Collections.emptyList()));
 
         final IOFileFilter filter = FileFilterUtils.trueFileFilter();
         List<File> filteredList = FileFilterUtils.filterList(filter, Collections.singletonList(null));
         assertEquals(1, filteredList.size());
-        assertEquals(null, filteredList.get(0));
+        assertNull(filteredList.get(0));
 
         filteredList = FileFilterUtils.filterList(filter, (List<File>) null);
         assertEquals(0, filteredList.size());
@@ -638,7 +661,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * Test method for {@link FileFilterUtils#filter(IOFileFilter, Path...)}.
      */
     @Test
-    public void testFilterPathsArrayNullParameters() throws Exception {
+    void testFilterPathsArrayNullParameters() throws Exception {
         final Path fileA = TestUtils.newFile(temporaryFolder, "A").toPath();
         final Path fileB = TestUtils.newFile(temporaryFolder, "B").toPath();
         assertThrows(NullPointerException.class, () -> PathUtils.filter(null, fileA, fileB));
@@ -655,7 +678,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * properly filters files from the set.
      */
     @Test
-    public void testFilterSet() throws Exception {
+    void testFilterSet() throws Exception {
         final File fileA = TestUtils.newFile(temporaryFolder, "A");
         final File fileB = TestUtils.newFile(temporaryFolder, "B");
         final Set<File> fileList = new HashSet<>(Arrays.asList(fileA, fileB));
@@ -673,7 +696,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * filters files from the set.
      */
     @Test
-    public void testFilterSet_fromArray() throws Exception {
+    void testFilterSet_fromArray() throws Exception {
         final File fileA = TestUtils.newFile(temporaryFolder, "A");
         final File fileB = TestUtils.newFile(temporaryFolder, "B");
 
@@ -690,7 +713,7 @@ public class FileFilterTest extends AbstractFilterTest {
      * parameters and {@code null} elements in the provided set.
      */
     @Test
-    public void testFilterSetNullParameters() {
+    void testFilterSetNullParameters() {
         assertThrows(NullPointerException.class, () -> FileFilterUtils.filterSet(null, Collections.emptySet()));
 
         final IOFileFilter filter = FileFilterUtils.trueFileFilter();
@@ -701,7 +724,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testHidden() throws IOException {
+    void testHidden() throws IOException {
         final File hiddenDirFile = new File(SVN_DIR_NAME);
         final Path hiddenDirPath = hiddenDirFile.toPath();
         if (hiddenDirFile.exists()) {
@@ -713,12 +736,14 @@ public class FileFilterTest extends AbstractFilterTest {
         final Path path = temporaryFolder.toPath();
         assertFiltering(HiddenFileFilter.HIDDEN, temporaryFolder, false);
         assertFiltering(HiddenFileFilter.HIDDEN, path, false);
+        assertFiltering(HiddenFileFilter.HIDDEN, (Path) null, true);
         assertFiltering(HiddenFileFilter.VISIBLE, temporaryFolder, true);
         assertFiltering(HiddenFileFilter.VISIBLE, path, true);
+        assertFiltering(HiddenFileFilter.VISIBLE, (Path) null, false);
     }
 
     @Test
-    public void testMagicNumberFileFilterBytes() throws Exception {
+    void testMagicNumberFileFilterBytes() throws Exception {
         final byte[] classFileMagicNumber = {(byte) 0xCA, (byte) 0xFE, (byte) 0xBA, (byte) 0xBE};
         final String xmlFileContent = "<?xml version=\"1.0\" encoding=\"UTF-8\">\n" + "<element>text</element>";
 
@@ -764,7 +789,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testMagicNumberFileFilterBytesOffset() throws Exception {
+    void testMagicNumberFileFilterBytesOffset() throws Exception {
         final byte[] tarMagicNumber = {0x75, 0x73, 0x74, 0x61, 0x72};
         final long tarMagicNumberOffset = 257;
 
@@ -799,7 +824,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testMagicNumberFileFilterString() throws Exception {
+    void testMagicNumberFileFilterString() throws Exception {
         final byte[] classFileMagicNumber = {(byte) 0xCA, (byte) 0xFE, (byte) 0xBA, (byte) 0xBE};
         final String xmlFileContent = "<?xml version=\"1.0\" encoding=\"UTF-8\">\n" + "<element>text</element>";
         final String xmlMagicNumber = "<?xml version=\"1.0\"";
@@ -830,7 +855,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testMagicNumberFileFilterStringOffset() throws Exception {
+    void testMagicNumberFileFilterStringOffset() throws Exception {
         final String tarMagicNumber = "ustar";
         final long tarMagicNumberOffset = 257;
 
@@ -865,7 +890,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testMagicNumberFileFilterValidation() {
+    void testMagicNumberFileFilterValidation() {
         assertThrows(NullPointerException.class, () -> new MagicNumberFileFilter((String) null, 0));
         assertThrows(IllegalArgumentException.class, () -> new MagicNumberFileFilter("0", -1));
         assertThrows(IllegalArgumentException.class, () -> new MagicNumberFileFilter("", 0));
@@ -875,7 +900,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testMakeCVSAware() throws Exception {
+    void testMakeCVSAware() throws Exception {
         final IOFileFilter filter1 = FileFilterUtils.makeCVSAware(null);
         final IOFileFilter filter2 = FileFilterUtils.makeCVSAware(FileFilterUtils.nameFileFilter("test-file1.txt"));
 
@@ -917,7 +942,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testMakeDirectoryOnly() throws Exception {
+    void testMakeDirectoryOnly() throws Exception {
         assertSame(DirectoryFileFilter.DIRECTORY, FileFilterUtils.makeDirectoryOnly(null));
 
         final IOFileFilter filter = FileFilterUtils.makeDirectoryOnly(FileFilterUtils.nameFileFilter("B"));
@@ -954,9 +979,8 @@ public class FileFilterTest extends AbstractFilterTest {
         fileB.delete();
     }
 
-    // -----------------------------------------------------------------------
     @Test
-    public void testMakeFileOnly() throws Exception {
+    void testMakeFileOnly() throws Exception {
         assertSame(FileFileFilter.INSTANCE, FileFilterUtils.makeFileOnly(null));
 
         final IOFileFilter filter = FileFilterUtils.makeFileOnly(FileFilterUtils.nameFileFilter("B"));
@@ -994,7 +1018,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testMakeSVNAware() throws Exception {
+    void testMakeSVNAware() throws Exception {
         final IOFileFilter filter1 = FileFilterUtils.makeSVNAware(null);
         final IOFileFilter filter2 = FileFilterUtils.makeSVNAware(FileFilterUtils.nameFileFilter("test-file1.txt"));
 
@@ -1036,12 +1060,15 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testNameFilter() throws IOException {
-        assertFooBarFileFiltering(new NameFileFilter("foo", "bar"));
+    void testNameFilter() throws IOException {
+        final NameFileFilter filter = new NameFileFilter("foo", "bar");
+        assertFooBarFileFiltering(filter);
+        assertFiltering(filter, (File) null, false);
+        assertFiltering(filter, (Path) null, false);
     }
 
     @Test
-    public void testNameFilterNullArgument() {
+    void testNameFilterNullArgument() {
         final String test = null;
         final String failMessage = "constructing a NameFileFilter with a null String argument should fail.";
         assertThrows(NullPointerException.class, () -> new NameFileFilter(test), failMessage);
@@ -1049,18 +1076,18 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testNameFilterNullArrayArgument() {
+    void testNameFilterNullArrayArgument() {
         assertThrows(NullPointerException.class, () -> new NameFileFilter((String[]) null));
     }
 
     @Test
-    public void testNameFilterNullListArgument() {
+    void testNameFilterNullListArgument() {
         final List<String> test = null;
         assertThrows(NullPointerException.class, () -> new NameFileFilter(test));
     }
 
     @Test
-    public void testNegate() throws IOException {
+    void testNegate() throws IOException {
         final IOFileFilter filter = FileFilterUtils.notFileFilter(FileFilterUtils.trueFileFilter());
         assertFiltering(filter, new File("foo.test"), false);
         assertFiltering(filter, new File("foo"), false);
@@ -1070,13 +1097,13 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testNullFilters() {
+    void testNullFilters() {
         assertThrows(NullPointerException.class, () -> FileFilterUtils.toList((IOFileFilter) null));
         assertThrows(NullPointerException.class, () -> FileFilterUtils.toList(new IOFileFilter[] {null}));
     }
 
     @Test
-    public void testOr() throws IOException {
+    void testOr() throws IOException {
         final IOFileFilter trueFilter = TrueFileFilter.INSTANCE;
         final IOFileFilter falseFilter = FalseFileFilter.INSTANCE;
         final File testFile = new File("foo.test");
@@ -1123,13 +1150,13 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testPathEqualsFilter() throws IOException {
+    void testPathEqualsFilter() throws IOException {
         assertFooBarFileFiltering(
             new PathEqualsFileFilter(Paths.get("foo")).or(new PathEqualsFileFilter(Paths.get("bar"))));
     }
 
     @Test
-    public void testPrefix() throws IOException {
+    void testPrefix() throws IOException {
         IOFileFilter filter = new PrefixFileFilter("foo", "bar");
         final File testFile = new File("test");
         final Path testPath = testFile.toPath();
@@ -1193,7 +1220,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testPrefixCaseInsensitive() throws IOException {
+    void testPrefixCaseInsensitive() throws IOException {
 
         IOFileFilter filter = new PrefixFileFilter(new String[] {"foo", "bar"}, IOCase.INSENSITIVE);
         assertFiltering(filter, new File("foo.test1"), true);
@@ -1228,7 +1255,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testSizeFilterOnFiles() throws Exception {
+    void testSizeFilterOnFiles() throws Exception {
         final File smallFile = new File(temporaryFolder, "small.txt");
         if (!smallFile.getParentFile().exists()) {
             fail("Cannot create file " + smallFile + " as the parent directory does not exist");
@@ -1275,7 +1302,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testSizeFilterOnPaths() throws Exception {
+    void testSizeFilterOnPaths() throws Exception {
         final Path smallFile = Paths.get(temporaryFolder.toString(), "small.txt");
         if (Files.notExists(smallFile.getParent())) {
             fail("Cannot create file " + smallFile + " as the parent directory does not exist");
@@ -1322,7 +1349,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testSuffix() throws IOException {
+    void testSuffix() throws IOException {
         IOFileFilter filter = new SuffixFileFilter("tes", "est");
         final File testFile = new File("test");
         final Path testPath = testFile.toPath();
@@ -1379,7 +1406,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testSuffixCaseInsensitive() throws IOException {
+    void testSuffixCaseInsensitive() throws IOException {
 
         IOFileFilter filter = new SuffixFileFilter(new String[] {"tes", "est"}, IOCase.INSENSITIVE);
         assertFiltering(filter, new File("foo.tes"), true);
@@ -1413,7 +1440,7 @@ public class FileFilterTest extends AbstractFilterTest {
     }
 
     @Test
-    public void testTrue() throws IOException {
+    void testTrue() throws IOException {
         final IOFileFilter filter = FileFilterUtils.trueFileFilter();
         assertFiltering(filter, new File("foo.test"), true);
         assertFiltering(filter, new File("foo"), true);
