@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -38,7 +38,7 @@ import org.junit.jupiter.api.Test;
 /**
  * Tests {@link IOBaseStream}.
  */
-public class IOBaseStreamTest {
+class IOBaseStreamTest {
 
     /**
      * Implements IOBaseStream with generics.
@@ -84,7 +84,7 @@ public class IOBaseStreamTest {
 
         private static final long serialVersionUID = 1L;
 
-        public MyRuntimeException(final String message) {
+        MyRuntimeException(final String message) {
             super(message);
         }
 
@@ -128,7 +128,7 @@ public class IOBaseStreamTest {
 
     @Test
     @AfterEach
-    public void testClose() {
+    void testClose() {
         baseStream.close();
         ioBaseStream.close();
         ioBaseStreamPath.close();
@@ -138,7 +138,7 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource") // @AfterEach
     @Test
-    public void testIsParallel() {
+    void testIsParallel() {
         assertFalse(baseStream.isParallel());
         assertFalse(ioBaseStream.isParallel());
         assertFalse(ioBaseStream.asBaseStream().isParallel());
@@ -148,7 +148,7 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource") // @AfterEach
     @Test
-    public void testIteratorPathIO() throws IOException {
+    void testIteratorPathIO() throws IOException {
         final AtomicReference<Path> ref = new AtomicReference<>();
         ioBaseStream.iterator().forEachRemaining(e -> ref.set(e.toRealPath()));
         assertEquals(TestConstants.ABS_PATH_B.toRealPath(), ref.get());
@@ -159,7 +159,7 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource") // @AfterEach
     @Test
-    public void testIteratorSimple() throws IOException {
+    void testIteratorSimple() throws IOException {
         final AtomicInteger ref = new AtomicInteger();
         baseStream.iterator().forEachRemaining(e -> ref.incrementAndGet());
         assertEquals(2, ref.get());
@@ -171,7 +171,7 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource")
     @Test
-    public void testOnClose() {
+    void testOnClose() {
         // Stream
         testOnClose(baseStream);
         testOnClose(ioBaseStream.asBaseStream());
@@ -202,7 +202,7 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource")
     @Test
-    public void testParallel() throws IOException {
+    void testParallel() throws IOException {
         final AtomicInteger ref = new AtomicInteger();
         baseStream.parallel().iterator().forEachRemaining(e -> ref.incrementAndGet());
         assertEquals(2, ref.get());
@@ -216,17 +216,17 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource") // @AfterEach
     @Test
-    public void testParallelParallel() {
-        try (final IOBaseStream<?, ?, ?> stream = createIOBaseStream()) {
+    void testParallelParallel() {
+        try (IOBaseStream<?, ?, ?> stream = createIOBaseStream()) {
             testParallelParallel(stream);
         }
-        try (final IOBaseStream<?, ?, ?> stream = createIOBaseStreamPath()) {
+        try (IOBaseStream<?, ?, ?> stream = createIOBaseStreamPath()) {
             testParallelParallel(stream);
         }
-        try (final IOBaseStream<?, ?, ?> stream = createIOBaseStream()) {
+        try (IOBaseStream<?, ?, ?> stream = createIOBaseStream()) {
             testParallelParallel(stream);
         }
-        try (final IOBaseStreamFixture<Path, ?, Stream<Path>> stream = createIOBaseStream()) {
+        try (IOBaseStreamFixture<Path, ?, Stream<Path>> stream = createIOBaseStream()) {
             testParallelParallel(stream.asBaseStream());
         }
     }
@@ -255,7 +255,7 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource")
     @Test
-    public void testSequential() throws IOException {
+    void testSequential() throws IOException {
         final AtomicInteger ref = new AtomicInteger();
         baseStream.sequential().iterator().forEachRemaining(e -> ref.incrementAndGet());
         assertEquals(2, ref.get());
@@ -267,14 +267,14 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource") // @AfterEach
     @Test
-    public void testSequentialSequential() {
-        try (final IOBaseStream<?, ?, ?> stream = createIOBaseStream()) {
+    void testSequentialSequential() {
+        try (IOBaseStream<?, ?, ?> stream = createIOBaseStream()) {
             testSequentialSequential(stream);
         }
-        try (final IOBaseStream<?, ?, ?> stream = createIOBaseStreamPath()) {
+        try (IOBaseStream<?, ?, ?> stream = createIOBaseStreamPath()) {
             testSequentialSequential(stream);
         }
-        try (final IOBaseStream<?, ?, ?> stream = createIOBaseStream()) {
+        try (IOBaseStream<?, ?, ?> stream = createIOBaseStream()) {
             testSequentialSequential(stream.asBaseStream());
         }
     }
@@ -303,7 +303,7 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource") // @AfterEach
     @Test
-    public void testSpliterator() {
+    void testSpliterator() {
         final AtomicInteger ref = new AtomicInteger();
         baseStream.spliterator().forEachRemaining(e -> ref.incrementAndGet());
         assertEquals(2, ref.get());
@@ -315,7 +315,7 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource")
     @Test
-    public void testUnordered() throws IOException {
+    void testUnordered() throws IOException {
         final AtomicInteger ref = new AtomicInteger();
         baseStream.unordered().iterator().forEachRemaining(e -> ref.incrementAndGet());
         assertEquals(2, ref.get());
@@ -327,7 +327,7 @@ public class IOBaseStreamTest {
 
     @SuppressWarnings("resource")
     @Test
-    public void testUnwrap() {
+    void testUnwrap() {
         final AtomicInteger ref = new AtomicInteger();
         baseStream.iterator().forEachRemaining(e -> ref.incrementAndGet());
         assertEquals(2, ref.get());
@@ -338,7 +338,7 @@ public class IOBaseStreamTest {
     }
 
     @Test
-    public void testWrap() {
+    void testWrap() {
         final Stream<Path> stream = createStreamOfPaths();
         @SuppressWarnings("resource")
         final IOStream<Path> wrap = ioBaseStreamAdapter.wrap(stream);
