@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -26,7 +26,7 @@ import java.util.function.Predicate;
 /**
  * Test fixtures for this package.
  */
-class TestConstants {
+final class TestConstants {
 
     static final Path ABS_PATH_A = Paths.get("LICENSE.txt").toAbsolutePath();
 
@@ -38,23 +38,27 @@ class TestConstants {
 
     static IOBinaryOperator<?> THROWING_IO_BINARY_OPERATOR = (t, u) -> throwIOException();
 
+    static IOBooleanSupplier THROWING_IO_BOOLEAN_SUPPLIER = TestConstants::throwIOException;
+
     static IOComparator<Object> THROWING_IO_COMPARATOR = (t, u) -> throwIOException();
 
     static IOConsumer<Object> THROWING_IO_CONSUMER = t -> throwIOException();
 
     static IOFunction<Object, Object> THROWING_IO_FUNCTION = t -> throwIOException();
 
-    static IOIntSupplier THROWING_IO_INT_SUPPLIER = () -> throwIOException();
+    static IOIntConsumer THROWING_IO_INT_CONSUMER = t -> throwIOException();
 
-    static IOLongSupplier THROWING_IO_LONG_SUPPLIER = () -> throwIOException();
+    static IOIntSupplier THROWING_IO_INT_SUPPLIER = TestConstants::throwIOException;
+
+    static IOLongSupplier THROWING_IO_LONG_SUPPLIER = TestConstants::throwIOException;
 
     static IOPredicate<Object> THROWING_IO_PREDICATE = t -> throwIOException();
 
     static IOQuadFunction<Object, Object, Object, Object, Object> THROWING_IO_QUAD_FUNCTION = (t, u, v, w) -> throwIOException();
 
-    static IORunnable THROWING_IO_RUNNABLE = () -> throwIOException();
+    static IORunnable THROWING_IO_RUNNABLE = TestConstants::throwIOException;
 
-    static IOSupplier<Object> THROWING_IO_SUPPLIER = () -> throwIOException();
+    static IOSupplier<Object> THROWING_IO_SUPPLIER = TestConstants::throwIOException;
 
     static IOTriConsumer<Object, Object, Object> THROWING_IO_TRI_CONSUMER = (t, u, v) -> throwIOException();
 
