@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -31,14 +31,14 @@ import org.junit.jupiter.api.Test;
 public class XmlStreamReaderUtilitiesTest {
 
     /** Mock {@link XmlStreamReader} implementation */
-    private static class MockXmlStreamReader extends XmlStreamReader {
+    private static final class MockXmlStreamReader extends XmlStreamReader {
         MockXmlStreamReader(final String defaultEncoding) throws IOException {
-            super(new StringInputStream(), null, true, defaultEncoding);
+            super(CharSequenceInputStream.builder().setCharSequence("").get(), null, true, defaultEncoding);
         }
     }
     private static final String RAWMGS1 = "encoding mismatch";
     private static final String RAWMGS2 = "unknown BOM";
-    private static final String HTTPMGS1 = "BOM must be NULL";
+    private static final String HTTPMGS1 = "BOM must be null";
     private static final String HTTPMGS2 = "encoding mismatch";
 
     private static final String HTTPMGS3 = "Illegal MIME";
@@ -56,7 +56,7 @@ public class XmlStreamReaderUtilitiesTest {
     protected String calculateHttpEncoding(final String httpContentType, final String bomEnc, final String xmlGuessEnc,
         final String xmlEnc, final boolean lenient, final String defaultEncoding) throws IOException {
         try (MockXmlStreamReader mock = new MockXmlStreamReader(defaultEncoding)) {
-            return mock.calculateHttpEncoding(httpContentType, bomEnc, xmlGuessEnc, xmlEnc, lenient);
+            return mock.calculateHttpEncoding(bomEnc, xmlGuessEnc, xmlEnc, lenient, httpContentType);
         }
     }
 
@@ -121,7 +121,7 @@ public class XmlStreamReaderUtilitiesTest {
         builder.append("xmlGuessEnc=[").append(xmlGuessEnc).append("], ");
         builder.append("xmlEnc=[").append(xmlEnc).append("], ");
         builder.append("defaultEncoding=[").append(defaultEncoding).append("],");
-        final String encoding = calculateRawEncoding(bomEnc,xmlGuessEnc,xmlEnc, defaultEncoding);
+        final String encoding = calculateRawEncoding(bomEnc, xmlGuessEnc, xmlEnc, defaultEncoding);
         assertEquals(expected, encoding, builder.toString());
     }
 
@@ -149,7 +149,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testAppXml() {
+    void testAppXml() {
         checkAppXml(false, null);
         checkAppXml(false, "");
         checkAppXml(true,  "application/xml");
@@ -165,7 +165,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testCalculateHttpEncoding() throws IOException {
+    void testCalculateHttpEncoding() throws IOException {
         // No BOM        Expected     Lenient cType           BOM         Guess       XML         Default
         checkHttpError(HTTPMGS3,      true,   null,           null,       null,       null,       null);
         checkHttpError(HTTPMGS3,      false,  null,           null,       null,       "UTF-8",    null);
@@ -190,7 +190,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testCalculateHttpEncodingUtf32() throws IOException {
+    void testCalculateHttpEncodingUtf32() throws IOException {
         // No BOM        Expected     Lenient cType           BOM         Guess       XML         Default
         checkHttpEncoding("UTF-32LE", true,   null,           null,       null,       "UTF-32LE", null);
         checkHttpEncoding("UTF-32BE", false,  TXTXML,         null,       null,       null,       "UTF-32BE");
@@ -207,7 +207,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testCalculateRawEncodingAdditionalUTF16() throws IOException {
+    void testCalculateRawEncodingAdditionalUTF16() throws IOException {
         //                           BOM         Guess       XML         Default
         checkRawError(RAWMGS1,       "UTF-16BE", "UTF-16",   null,       null);
         checkRawEncoding("UTF-16BE", "UTF-16BE", null,       "UTF-16",   null);
@@ -222,7 +222,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testCalculateRawEncodingAdditionalUTF32() throws IOException {
+    void testCalculateRawEncodingAdditionalUTF32() throws IOException {
         //                           BOM         Guess       XML         Default
         checkRawError(RAWMGS1,       "UTF-32BE", "UTF-32",   null,       null);
         checkRawEncoding("UTF-32BE", "UTF-32BE", null,       "UTF-32",   null);
@@ -237,7 +237,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testCalculateRawEncodingNoBOM() throws IOException {
+    void testCalculateRawEncodingNoBOM() throws IOException {
         // No BOM        Expected    BOM         Guess       XML         Default
         checkRawError(RAWMGS2,       "UTF-32",   null,       null,       null);
         //
@@ -255,7 +255,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testCalculateRawEncodingStandard() throws IOException {
+    void testCalculateRawEncodingStandard() throws IOException {
         // Standard BOM Checks           BOM         Other       Default
         testCalculateRawEncodingStandard("UTF-8",    "UTF-16BE", "UTF-16LE");
         testCalculateRawEncodingStandard("UTF-16BE", "UTF-8",    "UTF-16LE");
@@ -276,7 +276,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testCalculateRawEncodingStandardUtf32() throws IOException {
+    void testCalculateRawEncodingStandardUtf32() throws IOException {
         // Standard BOM Checks           BOM         Other       Default
         testCalculateRawEncodingStandard("UTF-8",    "UTF-32BE", "UTF-32LE");
         testCalculateRawEncodingStandard("UTF-32BE", "UTF-8",    "UTF-32LE");
@@ -284,7 +284,7 @@ public class XmlStreamReaderUtilitiesTest {
 }
 
     @Test
-    public void testContentTypeEncoding() {
+    void testContentTypeEncoding() {
         checkContentTypeEncoding(null, null);
         checkContentTypeEncoding(null, "");
         checkContentTypeEncoding(null, "application/xml");
@@ -303,7 +303,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testContentTypeMime() {
+    void testContentTypeMime() {
         checkContentTypeMime(null, null);
         checkContentTypeMime("", "");
         checkContentTypeMime("application/xml", "application/xml");
@@ -313,7 +313,7 @@ public class XmlStreamReaderUtilitiesTest {
     }
 
     @Test
-    public void testTextXml() {
+    void testTextXml() {
         checkTextXml(false, null);
         checkTextXml(false, "");
         checkTextXml(true,  "text/xml");
