@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,6 +16,7 @@
  */
 package org.apache.commons.io.output;
 
+import static org.apache.commons.io.output.ThresholdingOutputStreamTest.assertThresholdingInitialState;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
@@ -39,9 +40,15 @@ import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.MethodSource;
 
 /**
- * Tests {@code DeferredFileOutputStream}.
+ * Tests {@code DeferredFileOutputStream}. See also the superclass {@link ThresholdingOutputStream}.
+ *
+ * @see ThresholdingOutputStream
  */
-public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
+class DeferredFileOutputStreamTest extends AbstractTempDirTest {
+
+    private static void assertDeferredInitialState(final DeferredFileOutputStream out) {
+        assertTrue(out.isInMemory());
+    }
 
     public static IntStream data() {
         return IntStream.of(1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096);
@@ -60,21 +67,27 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
     /**
      * Tests the case where the amount of data exceeds the threshold, and is therefore written to disk. The actual data
      * written to disk is verified, as is the file itself.
+     *
+     * @param initialBufferSize the initial buffer size.
+     * @throws IOException on a test failure.
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testAboveThreshold(final int initialBufferSize) throws IOException {
+    void testAboveThreshold(final int initialBufferSize) throws IOException {
         final File testFile = Files.createTempFile(tempDirPath, "testAboveThreshold", "dat").toFile();
-        try (DeferredFileOutputStream dfos = DeferredFileOutputStream.builder()
-                .setThreshold(testBytes.length - 5)
+        final int threshold = testBytes.length - 5;
+        try (DeferredFileOutputStream out = DeferredFileOutputStream.builder()
+                .setThreshold(threshold)
                 .setBufferSize(initialBufferSize)
                 .setOutputFile(testFile)
                 .get()) {
-            dfos.write(testBytes, 0, testBytes.length);
-            dfos.close();
-            assertFalse(dfos.isInMemory());
-            assertNull(dfos.getData());
-            assertEquals(testFile.length(), dfos.getByteCount());
+            assertThresholdingInitialState(out, threshold, 0);
+            assertDeferredInitialState(out);
+            out.write(testBytes, 0, testBytes.length);
+            out.close();
+            assertFalse(out.isInMemory());
+            assertNull(out.getData());
+            assertEquals(testFile.length(), out.getByteCount());
             verifyResultFile(testFile);
         }
     }
@@ -86,18 +99,21 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testAboveThresholdGetInputStream(final int initialBufferSize, final @TempDir Path tempDir) throws IOException {
+    void testAboveThresholdGetInputStream(final int initialBufferSize, final @TempDir Path tempDir) throws IOException {
         final File testFile = Files.createTempFile(tempDirPath, "testAboveThreshold", "dat").toFile();
-        try (DeferredFileOutputStream dfos = DeferredFileOutputStream.builder()
-                .setThreshold(testBytes.length - 5)
+        final int threshold = testBytes.length - 5;
+        try (DeferredFileOutputStream out = DeferredFileOutputStream.builder()
+                .setThreshold(threshold)
                 .setBufferSize(initialBufferSize)
                 .setOutputFile(testFile)
                 .get()) {
-            dfos.write(testBytes, 0, testBytes.length);
-            dfos.close();
-            assertFalse(dfos.isInMemory());
-            assertEquals(testFile.length(), dfos.getByteCount());
-            try (InputStream is = dfos.toInputStream()) {
+            assertThresholdingInitialState(out, threshold, 0);
+            assertDeferredInitialState(out);
+            out.write(testBytes, 0, testBytes.length);
+            out.close();
+            assertFalse(out.isInMemory());
+            assertEquals(testFile.length(), out.getByteCount());
+            try (InputStream is = out.toInputStream()) {
                 assertArrayEquals(testBytes, IOUtils.toByteArray(is));
             }
             verifyResultFile(testFile);
@@ -106,22 +122,25 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
 
     /**
      * Tests the case where the amount of data is exactly the same as the threshold. The behavior should be the same as
-     * that for the amount of data being below (i.e. not exceeding) the threshold.
+     * that for the amount of data being below (not exceeding) the threshold.
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testAtThreshold(final int initialBufferSize) throws IOException {
-        try (DeferredFileOutputStream dfos = DeferredFileOutputStream.builder()
+    void testAtThreshold(final int initialBufferSize) throws IOException {
+        final int threshold = testBytes.length;
+        try (DeferredFileOutputStream out = DeferredFileOutputStream.builder()
             // @formatter:off
-                .setThreshold(testBytes.length)
+                .setThreshold(threshold)
                 .setBufferSize(initialBufferSize)
                 .get()) {
             // @formatter:on
-            dfos.write(testBytes, 0, testBytes.length);
-            dfos.close();
-            assertTrue(dfos.isInMemory());
-            assertEquals(testBytes.length, dfos.getByteCount());
-            final byte[] resultBytes = dfos.getData();
+            assertThresholdingInitialState(out, threshold, 0);
+            assertDeferredInitialState(out);
+            out.write(testBytes, 0, testBytes.length);
+            out.close();
+            assertTrue(out.isInMemory());
+            assertEquals(testBytes.length, out.getByteCount());
+            final byte[] resultBytes = out.getData();
             assertEquals(testBytes.length, resultBytes.length);
             assertArrayEquals(resultBytes, testBytes);
         }
@@ -133,18 +152,21 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testBelowThreshold(final int initialBufferSize) throws IOException {
-        try (DeferredFileOutputStream dfos = DeferredFileOutputStream.builder()
+    void testBelowThreshold(final int initialBufferSize) throws IOException {
+        final int threshold = testBytes.length + 42;
+        try (DeferredFileOutputStream out = DeferredFileOutputStream.builder()
             // @formatter:off
-                .setThreshold(testBytes.length + 42)
+                .setThreshold(threshold)
                 .setBufferSize(initialBufferSize)
                 .get()) {
             // @formatter:on
-            dfos.write(testBytes, 0, testBytes.length);
-            dfos.close();
-            assertTrue(dfos.isInMemory());
-            assertEquals(testBytes.length, dfos.getByteCount());
-            final byte[] resultBytes = dfos.getData();
+            assertThresholdingInitialState(out, threshold, 0);
+            assertDeferredInitialState(out);
+            out.write(testBytes, 0, testBytes.length);
+            out.close();
+            assertTrue(out.isInMemory());
+            assertEquals(testBytes.length, out.getByteCount());
+            final byte[] resultBytes = out.getData();
             assertEquals(testBytes.length, resultBytes.length);
             assertArrayEquals(resultBytes, testBytes);
         }
@@ -156,18 +178,21 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testBelowThresholdGetInputStream(final int initialBufferSize) throws IOException {
+    void testBelowThresholdGetInputStream(final int initialBufferSize) throws IOException {
         // @formatter:off
-        try (DeferredFileOutputStream dfos = DeferredFileOutputStream.builder()
-                .setThreshold(testBytes.length + 42)
+        final int threshold = testBytes.length + 42;
+        try (DeferredFileOutputStream out = DeferredFileOutputStream.builder()
+                .setThreshold(threshold)
                 .setBufferSize(initialBufferSize)
                 .get()) {
         // @formatter:on
-            dfos.write(testBytes, 0, testBytes.length);
-            dfos.close();
-            assertTrue(dfos.isInMemory());
-            assertEquals(testBytes.length, dfos.getByteCount());
-            try (InputStream is = dfos.toInputStream()) {
+            assertThresholdingInitialState(out, threshold, 0);
+            assertDeferredInitialState(out);
+            out.write(testBytes, 0, testBytes.length);
+            out.close();
+            assertTrue(out.isInMemory());
+            assertEquals(testBytes.length, out.getByteCount());
+            try (InputStream is = out.toInputStream()) {
                 assertArrayEquals(testBytes, IOUtils.toByteArray(is));
             }
         }
@@ -178,12 +203,13 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testTempFileAboveThreshold(final int initialBufferSize) throws IOException {
+    void testTempFileAboveThreshold(final int initialBufferSize) throws IOException {
         final String prefix = "commons-io-test";
         final String suffix = ".out";
         // @formatter:off
-        try (DeferredFileOutputStream dfos = DeferredFileOutputStream.builder()
-                .setThreshold(testBytes.length - 5)
+        final int threshold = testBytes.length - 5;
+        try (DeferredFileOutputStream out = DeferredFileOutputStream.builder()
+                .setThreshold(threshold)
                 .setBufferSize(initialBufferSize)
                 .setPrefix(prefix)
                 .setSuffix(suffix)
@@ -191,19 +217,21 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
                 .setDirectory(tempDirPath.toFile())
                 .get()) {
         // @formatter:on
-            assertNull(dfos.getFile(), "Check File is null-A");
-            assertNull(dfos.getPath(), "Check Path is null-A");
-            dfos.write(testBytes, 0, testBytes.length);
-            dfos.close();
-            assertFalse(dfos.isInMemory());
-            assertEquals(testBytes.length, dfos.getByteCount());
-            assertNull(dfos.getData());
-            assertNotNull(dfos.getFile(), "Check file not null");
-            assertTrue(dfos.getFile().exists(), "Check file exists");
-            assertTrue(dfos.getFile().getName().startsWith(prefix), "Check prefix");
-            assertTrue(dfos.getFile().getName().endsWith(suffix), "Check suffix");
-            assertEquals(tempDirPath, dfos.getPath().getParent(), "Check dir");
-            verifyResultFile(dfos.getFile());
+            assertThresholdingInitialState(out, threshold, 0);
+            assertDeferredInitialState(out);
+            assertNull(out.getFile(), "Check File is null-A");
+            assertNull(out.getPath(), "Check Path is null-A");
+            out.write(testBytes, 0, testBytes.length);
+            out.close();
+            assertFalse(out.isInMemory());
+            assertEquals(testBytes.length, out.getByteCount());
+            assertNull(out.getData());
+            assertNotNull(out.getFile(), "Check file not null");
+            assertTrue(out.getFile().exists(), "Check file exists");
+            assertTrue(out.getFile().getName().startsWith(prefix), "Check prefix");
+            assertTrue(out.getFile().getName().endsWith(suffix), "Check suffix");
+            assertEquals(tempDirPath, out.getPath().getParent(), "Check dir");
+            verifyResultFile(out.getFile());
         }
     }
 
@@ -213,12 +241,13 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testTempFileAboveThresholdPrefixOnly(final int initialBufferSize) throws IOException {
+    void testTempFileAboveThresholdPrefixOnly(final int initialBufferSize) throws IOException {
         final String prefix = "commons-io-test";
         final String suffix = null;
-        try (final DeferredFileOutputStream dfos = DeferredFileOutputStream.builder()
+        final int threshold = testBytes.length - 5;
+        try (DeferredFileOutputStream out = DeferredFileOutputStream.builder()
             // @formatter:off
-                .setThreshold(testBytes.length - 5)
+                .setThreshold(threshold)
                 .setBufferSize(initialBufferSize)
                 .setPrefix(prefix)
                 .setSuffix(suffix)
@@ -226,21 +255,23 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
                 .get()) {
             // @formatter:on
             try {
-                assertNull(dfos.getFile(), "Check File is null-A");
-                assertNull(dfos.getPath(), "Check Path is null-A");
-                dfos.write(testBytes, 0, testBytes.length);
-                dfos.close();
-                assertFalse(dfos.isInMemory());
-                assertNull(dfos.getData());
-                assertEquals(testBytes.length, dfos.getByteCount());
-                assertNotNull(dfos.getFile(), "Check file not null");
-                assertTrue(dfos.getFile().exists(), "Check file exists");
-                assertTrue(dfos.getFile().getName().startsWith(prefix), "Check prefix");
-                assertTrue(dfos.getFile().getName().endsWith(".tmp"), "Check suffix"); // ".tmp" is default
-                verifyResultFile(dfos.getFile());
+                assertThresholdingInitialState(out, threshold, 0);
+                assertDeferredInitialState(out);
+                assertNull(out.getFile(), "Check File is null-A");
+                assertNull(out.getPath(), "Check Path is null-A");
+                out.write(testBytes, 0, testBytes.length);
+                out.close();
+                assertFalse(out.isInMemory());
+                assertNull(out.getData());
+                assertEquals(testBytes.length, out.getByteCount());
+                assertNotNull(out.getFile(), "Check file not null");
+                assertTrue(out.getFile().exists(), "Check file exists");
+                assertTrue(out.getFile().getName().startsWith(prefix), "Check prefix");
+                assertTrue(out.getFile().getName().endsWith(".tmp"), "Check suffix"); // ".tmp" is default
+                verifyResultFile(out.getFile());
             } finally {
                 // Delete the temporary file.
-                dfos.getFile().delete();
+                out.getFile().delete();
             }
         }
     }
@@ -251,17 +282,20 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testTempFileBelowThreshold(final int initialBufferSize) throws IOException {
+    void testTempFileBelowThreshold(final int initialBufferSize) throws IOException {
         final String prefix = "commons-io-test";
         final String suffix = ".out";
-        try (final DeferredFileOutputStream dfos = new DeferredFileOutputStream(testBytes.length + 42, initialBufferSize, prefix, suffix, tempDirFile)) {
-            assertNull(dfos.getFile(), "Check File is null-A");
-            assertNull(dfos.getPath(), "Check Path is null-A");
-            dfos.write(testBytes, 0, testBytes.length);
-            dfos.close();
-            assertTrue(dfos.isInMemory());
-            assertEquals(testBytes.length, dfos.getByteCount());
-            assertNull(dfos.getFile(), "Check file is null-B");
+        final int threshold = testBytes.length + 42;
+        try (DeferredFileOutputStream out = new DeferredFileOutputStream(threshold, initialBufferSize, prefix, suffix, tempDirFile)) {
+            assertThresholdingInitialState(out, threshold, 0);
+            assertDeferredInitialState(out);
+            assertNull(out.getFile(), "Check File is null-A");
+            assertNull(out.getPath(), "Check Path is null-A");
+            out.write(testBytes, 0, testBytes.length);
+            out.close();
+            assertTrue(out.isInMemory());
+            assertEquals(testBytes.length, out.getByteCount());
+            assertNull(out.getFile(), "Check file is null-B");
         }
     }
 
@@ -271,7 +305,7 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      * @throws Exception
      */
     @Test
-    public void testTempFileError() throws Exception {
+    void testTempFileError() throws Exception {
         final String prefix = null;
         final String suffix = ".out";
         assertThrows(NullPointerException.class, () -> new DeferredFileOutputStream(testBytes.length - 5, prefix, suffix, tempDirFile));
@@ -283,18 +317,20 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testThresholdNegative(final int initialBufferSize) throws IOException {
+    void testThresholdNegative(final int initialBufferSize) throws IOException {
         final File testFile = Files.createTempFile(tempDirPath, "testThresholdNegative", "dat").toFile();
-        try (DeferredFileOutputStream dfos = DeferredFileOutputStream.builder()
+        try (DeferredFileOutputStream out = DeferredFileOutputStream.builder()
                 .setThreshold(-1)
                 .setBufferSize(initialBufferSize)
                 .setOutputFile(testFile)
                 .get()) {
-            dfos.write(testBytes, 0, testBytes.length);
-            dfos.close();
-            assertFalse(dfos.isInMemory());
-            assertNull(dfos.getData());
-            assertEquals(testFile.length(), dfos.getByteCount());
+            assertThresholdingInitialState(out, 0, 0);
+            assertDeferredInitialState(out);
+            out.write(testBytes, 0, testBytes.length);
+            out.close();
+            assertFalse(out.isInMemory());
+            assertNull(out.getData());
+            assertEquals(testFile.length(), out.getByteCount());
             verifyResultFile(testFile);
         }
     }
@@ -306,23 +342,26 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testThresholdReached(final int initialBufferSize) throws IOException {
+    void testThresholdReached(final int initialBufferSize) throws IOException {
         final File testFile = Files.createTempFile(tempDirPath, "testThresholdReached", "dat").toFile();
-        try (final DeferredFileOutputStream dfos = DeferredFileOutputStream.builder()
+        final int threshold = testBytes.length / 2;
+        try (DeferredFileOutputStream out = DeferredFileOutputStream.builder()
             // @formatter:off
-                .setThreshold(testBytes.length /2)
+                .setThreshold(threshold)
                 .setBufferSize(initialBufferSize)
                 .setOutputFile(testFile)
                 .get()) {
             // @formatter:on
+            assertThresholdingInitialState(out, threshold, 0);
+            assertDeferredInitialState(out);
             final int chunkSize = testBytes.length / 3;
-            dfos.write(testBytes, 0, chunkSize);
-            dfos.write(testBytes, chunkSize, chunkSize);
-            dfos.write(testBytes, chunkSize * 2, testBytes.length - chunkSize * 2);
-            dfos.close();
-            assertFalse(dfos.isInMemory());
-            assertNull(dfos.getData());
-            assertEquals(testBytes.length, dfos.getByteCount());
+            out.write(testBytes, 0, chunkSize);
+            out.write(testBytes, chunkSize, chunkSize);
+            out.write(testBytes, chunkSize * 2, testBytes.length - chunkSize * 2);
+            out.close();
+            assertFalse(out.isInMemory());
+            assertNull(out.getData());
+            assertEquals(testBytes.length, out.getByteCount());
             verifyResultFile(testFile);
         }
     }
@@ -332,18 +371,18 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testWriteToLarge(final int initialBufferSize) throws IOException {
+    void testWriteToLarge(final int initialBufferSize) throws IOException {
         final File testFile = Files.createTempFile(tempDirPath, "testWriteToFile", "dat").toFile();
+        final int threshold = testBytes.length / 2;
         try (ByteArrayOutputStream baos = new ByteArrayOutputStream(initialBufferSize);
-                DeferredFileOutputStream dfos = DeferredFileOutputStream.builder().setThreshold(testBytes.length / 2).setOutputFile(testFile).get()) {
+                DeferredFileOutputStream dfos = DeferredFileOutputStream.builder().setThreshold(threshold).setOutputFile(testFile).get()) {
+            assertThresholdingInitialState(dfos, threshold, 0);
+            assertDeferredInitialState(dfos);
             dfos.write(testBytes);
-
             assertTrue(testFile.exists());
             assertFalse(dfos.isInMemory());
             assertEquals(testBytes.length, dfos.getByteCount());
-
             assertThrows(IOException.class, () -> dfos.writeTo(baos));
-
             dfos.close();
             dfos.writeTo(baos);
             final byte[] copiedBytes = baos.toByteArray();
@@ -357,18 +396,18 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testWriteToLargeCtor(final int initialBufferSize) throws IOException {
+    void testWriteToLargeCtor(final int initialBufferSize) throws IOException {
         final File testFile = Files.createTempFile(tempDirPath, "testWriteToFile", "dat").toFile();
+        final int threshold = testBytes.length / 2;
         try (ByteArrayOutputStream baos = new ByteArrayOutputStream(initialBufferSize);
-                DeferredFileOutputStream dfos = new DeferredFileOutputStream(testBytes.length / 2, testFile)) {
+                DeferredFileOutputStream dfos = new DeferredFileOutputStream(threshold, testFile)) {
+            assertThresholdingInitialState(dfos, threshold, 0);
+            assertDeferredInitialState(dfos);
             dfos.write(testBytes);
-
             assertTrue(testFile.exists());
             assertFalse(dfos.isInMemory());
-
             assertThrows(IOException.class, () -> dfos.writeTo(baos));
             assertEquals(testBytes.length, dfos.getByteCount());
-
             dfos.close();
             dfos.writeTo(baos);
             final byte[] copiedBytes = baos.toByteArray();
@@ -383,17 +422,17 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      */
     @ParameterizedTest(name = "initialBufferSize = {0}")
     @MethodSource("data")
-    public void testWriteToSmall(final int initialBufferSize) throws IOException {
+    void testWriteToSmall(final int initialBufferSize) throws IOException {
         final File testFile = Files.createTempFile(tempDirPath, "testWriteToMem", "dat").toFile();
+        final int threshold = testBytes.length * 2;
         try (ByteArrayOutputStream baos = new ByteArrayOutputStream(initialBufferSize);
-                final DeferredFileOutputStream dfos = new DeferredFileOutputStream(testBytes.length * 2, initialBufferSize, testFile)) {
+                DeferredFileOutputStream dfos = new DeferredFileOutputStream(threshold, initialBufferSize, testFile)) {
+            assertThresholdingInitialState(dfos, threshold, 0);
+            assertDeferredInitialState(dfos);
             dfos.write(testBytes);
-
             assertTrue(dfos.isInMemory());
-
             assertThrows(IOException.class, () -> dfos.writeTo(baos));
             assertEquals(testBytes.length, dfos.getByteCount());
-
             dfos.close();
             dfos.writeTo(baos);
             final byte[] copiedBytes = baos.toByteArray();
@@ -407,7 +446,7 @@ public class DeferredFileOutputStreamTest extends AbstractTempDirTest {
      * @param testFile The file containing the test output.
      */
     private void verifyResultFile(final File testFile) throws IOException {
-        try (final InputStream fis = Files.newInputStream(testFile.toPath())) {
+        try (InputStream fis = Files.newInputStream(testFile.toPath())) {
             assertEquals(testBytes.length, fis.available());
 
             final byte[] resultBytes = new byte[testBytes.length];
