@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,10 +23,10 @@ import org.junit.jupiter.api.Test;
 /**
  * Tests {@link NullAppendable}.
  */
-public class NullAppendableTest {
+class NullAppendableTest {
 
     @Test
-    public void testNull() throws IOException {
+    void testNull() throws IOException {
         final Appendable appendable = NullAppendable.INSTANCE;
         appendable.append('a');
         appendable.append("A");
