@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,16 +16,14 @@
  */
 package org.apache.commons.io.output;
 
-
 import java.io.IOException;
 
 import org.junit.jupiter.api.Test;
 
-
 /**
- * Really not a lot to do here, but checking that no Exceptions are thrown.
+ * Tests {@link NullPrintStream}.
  */
-public class NullPrintStreamTest {
+class NullPrintStreamTest {
 
     private void process(final NullPrintStream nos) throws IOException {
         nos.write("string".getBytes());
@@ -39,14 +37,14 @@ public class NullPrintStreamTest {
     }
 
     @Test
-    public void testNullNewInstance() throws IOException {
+    void testNullNewInstance() throws IOException {
         try (NullPrintStream nos = new NullPrintStream()) {
             process(nos);
         }
     }
 
     @Test
-    public void testNullSingleton() throws IOException {
+    void testNullSingleton() throws IOException {
         try (NullPrintStream nos = NullPrintStream.INSTANCE) {
             process(nos);
         }
